@@ -18,8 +18,6 @@
 */
 
 use std::ops::{BitAnd, Shl};
-use std::cell::Ref;
-use std::cell::{Cell, RefCell};
 use std::mem::zeroed;
 use std::ffi::CString;
 
@@ -279,162 +277,6 @@ impl BitAnd<LogMask> for i32
     }
 }
 
-/// An internal structure which contains the setup fields
-
-pub(crate) struct SyslogOption
-{
-    /// A identification i.e program name, thread name
-    logtag: RefCell<Option<String>>, 
-
-    /// Defines how syslog operates
-    logstat: LogStat,
-
-    /// Holds the facility 
-    facility: LogFacility,
-
-    /// A logmask
-    logmask: Cell<i32>,
-}
-
-
-unsafe impl Sync for SyslogOption{}
-unsafe impl Send for SyslogOption{}
-
-impl SyslogOption
-{
-    /// Trancates the string up to n UTF8 chars if string exceeds size
-    /// 
-    /// # Arguments
-    ///
-    /// * `lt` - a string to truncate
-    ///
-    /// * `n` - a size
-    /// 
-    /// # Returns 
-    ///
-    /// * The new instance of String even if no action was required
-    pub(crate) fn truncate(lt: &str, n: usize) -> String
-    {
-        let ltt =
-            match lt.char_indices().nth(n) 
-            {
-                None => lt,
-                Some((idx, _)) => &lt[..idx],
-            };
-
-        return ltt.to_string();
-    }
-}
-
-impl SyslogOption
-{
-    /// Creates new instance of [SyslogOption].
-    ///
-    /// # Arguments
-    ///
-    /// * `ident` - An optional argument which takes ref to str. If none, the
-    ///     ident will be set later. Yje ident will be trucated to 48 UTF8
-    ///     chars.
-    /// 
-    /// * `logstat` - A [LogStat] flags separated by '|'
-    /// 
-    /// * `facility` - A [LogFacility] flag
-    ///
-    /// # Returns
-    ///
-    /// * The instance of the [SyslogOption]. Never fails.
-    pub(crate) fn new(
-        ident: Option<&str>, 
-        logstat: LogStat, 
-        facility: LogFacility) -> Self
-    {
-        // check if log_facility is invalid
-        let log_facility =
-            if facility.is_empty() == false && 
-                (facility & !LogMask::LOG_FACMASK).is_empty() == true
-            {
-                facility
-            }
-            else
-            {
-                // default facility code
-                LogFacility::LOG_USER
-            };
-
-        let ident = match ident
-            {
-                Some(r) => Some(Self::truncate(r, 48)),
-                None => None,
-            };
-        
-        return 
-            SyslogOption
-            {
-                logtag: RefCell::new(ident),
-                logstat: logstat, 
-                facility: log_facility,
-                logmask: Cell::new(0xff),
-            };
-    }
-
-    pub(crate) fn is_logstat_flag(&self, flag: LogStat) -> bool
-    {
-        return self.logstat.intersects(flag);
-    }
-
-    pub(crate) fn get_logfacility(&self) -> LogFacility
-    {
-        return self.facility;
-    }
-
-    pub(crate) fn exists_logtag(&self) -> bool
-    {
-        return self.logtag.borrow().is_some();
-    }
-
-    pub(crate) fn get_logtag(&self) -> Ref<'_, Option<String>>
-    {
-        return self.logtag.borrow();
-    }
-
-    pub(crate) fn set_logtag<L: AsRef<str>>(&self, logtag: L)
-    {
-        *self.logtag.borrow_mut() = 
-            Some(Self::truncate(logtag.as_ref(), 48));
-    }
-
-    pub(crate) fn set_logmask(&self, logmask: i32) -> i32
-    {
-        let oldmask = self.logmask.get();
-
-        if logmask != 0
-        {
-            self.logmask.set(logmask);
-        }
-
-        return oldmask;
-    }
-
-    pub(crate) fn is_logmasked(&self, pri: i32) -> bool
-    {
-        if ((1 << (pri & LogMask::LOG_PRIMASK)) & self.logmask.get()) == 0
-        {
-            return true;
-        }
-
-        return false;
-    }
-
-    pub(crate) fn send_to_stderr(&self, msg: &mut [u8])
-    {
-        if self.is_logstat_flag(LogStat::LOG_PERROR) == true
-        {
-            let mut newline = String::from("\n");
-            send_to_stderr(libc::STDERR_FILENO, msg, &mut newline);
-        }
-    }
-}
-
 /// A function which uses [libc::iovec] to send message to FD.
 /// This function uses unsafe code
 ///
@@ -489,6 +331,29 @@ pub(crate) fn truncate(lt: &str) -> &str
     return ltt;
 }
 
+/// Trancates the string up to n UTF8 chars if string exceeds size
+/// 
+/// # Arguments
+///
+/// * `lt` - a string to truncate
+///
+/// * `n` - a size
+/// 
+/// # Returns 
+///
+/// * The new instance of String even if no action was required
+pub(crate) fn truncate_n(lt: &str, n: usize) -> String
+    {
+        let ltt =
+            match lt.char_indices().nth(n) 
+            {
+                None => lt,
+                Some((idx, _)) => &lt[..idx],
+            };
+
+        return ltt.to_string();
+    }
+
 /// This function validates the pri for the incorrects bits set.
 /// If bits are set incorrectly, resets the invalid bits with:
 /// *pri & (LogMask::LOG_PRIMASK | LogMask::LOG_FACMASK).
@@ -525,77 +390,9 @@ fn test_truncate()
     assert_eq!("cat", trunc);
 }
 
-#[test]
-fn test_bit_operations()
-{
-    let correct = 
-        SyslogOption::new(Some("test1"), LogStat::LOG_PID, LogFacility::LOG_DAEMON);
-
-    assert_eq!(correct.facility, LogFacility::LOG_DAEMON);
-    assert_eq!((correct.facility & !LogFacility::LOG_DAEMON), LogFacility::empty());
-}
-
-#[test]
-fn test_bit_operations2()
-{
-    let _correct = 
-        SyslogOption::new(Some("test2"), LogStat::LOG_PID, LogFacility::LOG_DAEMON);
-
-    let mut pri = Priority::LOG_ALERT.bits();
-
-    let res = check_invalid_bits(&mut pri);
-
-    assert_eq!(res.is_ok(), true);
-    assert_eq!(pri, Priority::LOG_ALERT.bits());
-}
-
 #[test]
 fn test_priority_shl()
 {
     assert_eq!((1 << 5), (1 << Priority::LOG_NOTICE));
 }
 
-#[test]
-fn test_set_priority()
-{
-    let correct = 
-        SyslogOption::new(Some("test1"), LogStat::LOG_PID, LogFacility::LOG_DAEMON);
-
-    let ret = correct.set_logmask(LOG_MASK!(Priority::LOG_ERR));
-
-    assert_eq!(ret, 0xff);
-
-    let ret = correct.set_logmask(LOG_MASK!(Priority::LOG_ERR));
-
-    assert_eq!(ret, LOG_MASK!(Priority::LOG_ERR));
-
-    let ret = correct.is_logmasked(Priority::LOG_WARNING.bits());
-    assert_eq!(ret, true);
-
-    let ret = correct.is_logmasked(Priority::LOG_ERR.bits());
-    assert_eq!(ret, false);
-
-    let ret = correct.is_logmasked(Priority::LOG_CRIT.bits());
-    assert_eq!(ret, true);
-}
-
-#[test]
-fn test_set_priority2()
-{
-    let correct = 
-        SyslogOption::new(Some("test1"), LogStat::LOG_PID, LogFacility::LOG_DAEMON);
-
-    let ret = correct.set_logmask(!LOG_MASK!(Priority::LOG_ERR));
-
-    assert_eq!(ret, 0xff);
-
-    let ret = correct.is_logmasked(Priority::LOG_WARNING.bits());
-    assert_eq!(ret, false);
-
-    let ret = correct.is_logmasked(Priority::LOG_ERR.bits());
-    assert_eq!(ret, true);
-
-    let ret = correct.is_logmasked(Priority::LOG_CRIT.bits());
-    assert_eq!(ret, false);
-}
-
