@@ -43,17 +43,20 @@ extern "C" {
 /// Reutns the current process name, if available
 pub(crate) fn p_getprogname() -> Option<String>
 {
-    #[cfg(any(
-        target_os = "freebsd",
-        target_os = "dragonfly",
-        target_os = "openbsd",
-        target_os = "netbsd",
-        target_os = "macos"
-    ))]
-    let pn = unsafe { getprogname() };
+    let pn =
+        {
+            #[cfg(any(
+                target_os = "freebsd",
+                target_os = "dragonfly",
+                target_os = "openbsd",
+                target_os = "netbsd",
+                target_os = "macos"
+            ))]
+            unsafe { getprogname() }
 
-    #[cfg(target_os = "linux")]
-    let pn = unsafe{ program_invocation_name };
+            #[cfg(target_os = "linux")]
+            unsafe{ program_invocation_name }
+        };
 
     let temp = unsafe {CStr::from_ptr(pn)};
 
