@@ -17,10 +17,8 @@
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
-use std::mem::MaybeUninit;
 
 use tokio::time::{sleep, Duration};
-
 use tokio::sync::Mutex;
 
 use async_recursion::async_recursion;
@@ -145,7 +143,7 @@ impl SyslogInternal
     pub fn set_logtag<L: AsRef<str>>(&mut self, logtag: L)
     {
         self.logtag = 
-            Some(SyslogOption::truncate(logtag.as_ref(), 48));
+            Some(truncate_n(logtag.as_ref(), 48));
     }
 
     /// Disconnects the unix stream from syslog.
@@ -165,42 +163,8 @@ impl SyslogInternal
     /// Should be called only when lock is acuired
     fn connectlog(&mut self) -> SyRes<()>
     {
-        // try priv socket
         let stream = SyslogSocket::connect()?;
 
-        let mut len: MaybeUninit<libc::socklen_t> = std::mem::MaybeUninit::uninit();
-        // set the sndbuf len
-        let res = unsafe
-            {
-                libc::getsockopt(
-                    stream.get_raw_fd(), 
-                    libc::SOL_SOCKET, 
-                    libc::SO_SNDBUF, 
-                    len.as_mut_ptr() as *mut libc::c_void, 
-                    &mut {std::mem::size_of::<libc::socklen_t>() as libc::socklen_t} 
-                )
-            };
-
-        if res == 0
-        {
-            let mut len = unsafe { len.assume_init() };
-
-            if len < MAXLINE
-            {
-                len = MAXLINE;
-
-                unsafe {
-                    libc::setsockopt(
-                        stream.get_raw_fd(), 
-                        libc::SOL_SOCKET, 
-                        libc::SO_SNDBUF, 
-                        &len as *const _ as *const libc::c_void, 
-                        std::mem::size_of::<libc::socklen_t>() as libc::socklen_t
-                    )
-                };
-            }
-        }
-
         self.stream = stream;
 
         return Ok(());
@@ -275,7 +239,7 @@ impl SyslogInternal
         // message based on RFC 3164
         let msg_pri = 
             [
-                "<".as_bytes(), pri.to_string().as_bytes(), ">".as_bytes()
+                b"<", pri.to_string().as_bytes(), b">"
             ].concat();
 
         let msg_header = 
@@ -289,11 +253,11 @@ impl SyslogInternal
         let mut msg = 
             [
                 // appname
-                " ".as_bytes(), progname.as_bytes(), 
+                b" ", progname.as_bytes(), 
                 // PID
-                "[".as_bytes(), portable::get_pid().to_string().as_str().as_bytes(), "]:".as_bytes(),
+                b"[", portable::get_pid().to_string().as_str().as_bytes(), b"]:",
                 // msg
-                " ".as_bytes(), /*b"\xEF\xBB\xBF",*/ msg_final.as_bytes()
+                b" ", /*b"\xEF\xBB\xBF",*/ msg_final.as_bytes()
             ].concat();
 
         drop(progname);
@@ -460,29 +424,29 @@ impl SyslogInternal
         // message based on RFC 5424
         let msg_pri = 
             [
-                "<".as_bytes(), pri.to_string().as_bytes(), ">1".as_bytes()
+                b"<", pri.to_string().as_bytes(), b">1"
             ].concat();
 
         let msg_header = 
             [ 
                 // timedate
-                " ".as_bytes(), timedate.as_bytes(), 
+                b" ", timedate.as_bytes(), 
                 // hostname
-                " ".as_bytes(), hostname.as_bytes(), 
+                b" ", hostname.as_bytes(), 
             ].concat();
         
         let mut msg = 
             [
                 // appname
-                " ".as_bytes(), progname.as_bytes(), 
+                b" ", progname.as_bytes(), 
                 // PID
-                " ".as_bytes(), portable::get_pid().to_string().as_str().as_bytes(),
+                b" ", portable::get_pid().to_string().as_str().as_bytes(),
                 // message ID
-                " ".as_bytes(), NILVALUE.as_bytes(), 
+                b" ", NILVALUE.as_bytes(), 
                 // structured data
-                " ".as_bytes(), NILVALUE.as_bytes(), 
+                b" ", NILVALUE.as_bytes(), 
                 // msg
-                " ".as_bytes(), /*b"\xEF\xBB\xBF",*/ msg_final.as_bytes()
+                b" ", /*b"\xEF\xBB\xBF",*/ msg_final.as_bytes()
             ].concat();
         
         // output to stderr if required
@@ -577,8 +541,7 @@ impl SyslogInternal
 /// A common instance which describes the syslog state
 pub struct Syslog
 {   
-    /// A multithreading sync lock. A giant lock which used for access
-    /// to both - stream and [SyslogOption]
+    /// A giant lock to synchronize the access to assets of the [SyslogInternal]
     lock: Mutex<SyslogInternal>,
 }
 
@@ -641,7 +604,7 @@ impl Syslog
 
     /// Sets the logmask to filter out the syslog calls.
     /// 
-    /// See macroses [common::LOG_MASK] and [common::LOG_UPTO] to generate mask
+    /// See macroses [LOG_MASK] and [LOG_UPTO] to generate mask
     ///
     /// # Example
     ///
@@ -732,7 +695,7 @@ impl Syslog
     }
 }
 
-#[tokio::test(flavor = "multi_thread", worker_threads = 2)]
+#[tokio::test(flavor = "multi_thread", worker_threads = 1)]
 async fn test_multithreading()
 {
     use std::sync::Arc;
